# coding: utf-8

"""
    marax-server-sdk

    Marax Server SDK to send transactional events from client server to marax server  # noqa: E501

    The version of the OpenAPI document: 0.3.0
    Contact: team@marax.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import marax_server_sdk
from marax_server_sdk.models.request_body_properties_reward import RequestBodyPropertiesReward  # noqa: E501
from marax_server_sdk.rest import ApiException

class TestRequestBodyPropertiesReward(unittest.TestCase):
    """RequestBodyPropertiesReward unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RequestBodyPropertiesReward
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = marax_server_sdk.models.request_body_properties_reward.RequestBodyPropertiesReward()  # noqa: E501
        if include_optional :
            return RequestBodyPropertiesReward(
                id = '0', 
                expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                timezone = 'Asia/Kolkata', 
                promocode = 'SWIGGYIT', 
                title = 'Flat Rs 100/- off', 
                body = 'Applicable on all order above', 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                type = 'monetory', 
                ui = 'scratch_card', 
                handled_by = 'marax'
            )
        else :
            return RequestBodyPropertiesReward(
        )

    def testRequestBodyPropertiesReward(self):
        """Test RequestBodyPropertiesReward"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    marax-server-sdk

    Marax Server SDK to send transactional events from client server to marax server  # noqa: E501

    The version of the OpenAPI document: 0.3.0
    Contact: team@marax.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from marax_server_sdk.models.request_body import RequestBody
from marax_server_sdk.models.request_body_properties import RequestBodyProperties
from marax_server_sdk.models.request_body_properties_fulfillment import RequestBodyPropertiesFulfillment
from marax_server_sdk.models.request_body_properties_products import RequestBodyPropertiesProducts
from marax_server_sdk.models.request_body_properties_reward import RequestBodyPropertiesReward
from marax_server_sdk.models.request_body_properties_total_cart_price import RequestBodyPropertiesTotalCartPrice
from marax_server_sdk.models.request_body_properties_total_discount import RequestBodyPropertiesTotalDiscount
from marax_server_sdk.models.request_body_properties_total_order_price import RequestBodyPropertiesTotalOrderPrice
from marax_server_sdk.models.response200 import Response200
from marax_server_sdk.models.response400 import Response400
from marax_server_sdk.models.response500 import Response500



# coding: utf-8

"""
    marax-server-sdk

    Marax Server SDK to send transactional events from client server to marax server  # noqa: E501

    The version of the OpenAPI document: 0.3.0
    Contact: team@marax.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six
import json
import jwt
from datetime import datetime

from marax_server_sdk.api_client import ApiClient
from marax_server_sdk.exceptions import (
    ApiTypeError,
    ApiValueError
)


class RewardApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def process_event(self, client, **kwargs):  # noqa: E501
        """Perform reward post-processing  # noqa: E501

        Process events like ORDER_COMPLETED and do the necessary changes to the validity of the reward object (if applicable) (Eg., increasing the count of reward redeemed, changing reward status to redeemed)   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_event(client, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str client: Id of the client obtained from MARS dashboard (required)
        :param RequestBody request_body: Details of transactional event
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Response200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.process_event_with_http_info(client, **kwargs)  # noqa: E501

    def process_event_with_http_info(self, client, **kwargs):  # noqa: E501
        """Perform reward post-processing  # noqa: E501

        Process events like ORDER_COMPLETED and do the necessary changes to the validity of the reward object (if applicable) (Eg., increasing the count of reward redeemed, changing reward status to redeemed)   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_event_with_http_info(client, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str client: Id of the client obtained from MARS dashboard (required)
        :param RequestBody request_body: Details of transactional event
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Response200, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['client', 'request_body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method process_event" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'client' is set
        if self.api_client.client_side_validation and ('client' not in local_var_params or  # noqa: E501
                                                        local_var_params['client'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `client` when calling `process_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'client' in local_var_params:
            path_params['client'] = local_var_params['client']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/reward/v1/{client}/post-process', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Response200',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
    def reward_checker(self,current_cart_state,jwt_token,client_key):

        def objects_equal(o1, o2):
            if(o1==o2):
                return True
            else:
                return False
        
        def array_equal(ar1, ar2):
            if(ar1==None and ar2==None):
                return True
            if(len(ar1) != len(ar2)):
                return False
            flag2 = 1
            for i in range(len(ar1)):
                flag1 = 0
                for j in range(len(ar2)):
                    if(objects_equal(ar1[i], ar2[j])):
                        flag1 = 1
                        break
                if(flag1 == 0):
                    flag2 = 0
                    break
            if(flag2 == 0):
                return False
            else:
                return True

        try:
            decoded=jwt.decode(jwt_token, client_key, algorithms='RS512',verify=True)
        except Exception as e:
            return(
                json.dumps(
                    {
                        "isValid":False,
                        "message":"Invalid JWT",
                        "reward": None
                }))
        try:
            verified=0
            if(isinstance(current_cart_state,str)):
                current_cart_state=json.loads(current_cart_state)

            if(current_cart_state["maraxId"]==decoded["maraxId"]):
                verified+=1
            else:
                # print("hello")
                raise Exception("idMatchError")
            if(current_cart_state["paymentMode"]==decoded["paymentMode"]):
                verified+=1
            else:
                raise Exception("paymentModeMatchError")
            if(objects_equal(current_cart_state["totalOrderPrice"],decoded["totalOrderPrice"])):
                verified+=1
            else:
                # print("hell")
                raise Exception("orderPriceMatchError")
            if(objects_equal(current_cart_state["totalCartPrice"],decoded["totalCartPrice"])):
                verified+=1
            else:
                raise Exception("cartPriceMatchError")
            if(objects_equal(current_cart_state["totalDiscount"],decoded["totalDiscount"])):
                verified+=1
            else:
                raise Exception("discountMatchError")
            if(array_equal(current_cart_state["fulfillment"],decoded["fulfillment"])):
                verified+=1
            else:
                raise Exception("fulfillmentMatchError")
            if(array_equal(current_cart_state["products"],decoded["products"])):
                verified+=1
            else:
                raise Exception("productMatchError")
            if(datetime.utcnow()<=datetime.strptime(decoded["reward"]["expiry"],'%Y-%m-%dT%H:%M:%S.%fZ')):
                verified+=1
            else:
                raise Exception("rewardExpiredError")
            # return("verified: "+verified)
            if(verified==8):
                return(json.dumps(
                    {
                        "isValid":True,
                        "reward":decoded["reward"],
                        "message":"success"
                }))
       
        except Exception as err:
            if(str(err)=="idMatchError"):
                return(
                    json.dumps(
                        {
                            "isValid":False,
                            "message":"Marax Id not matching!",
                            "reward": None
                    }))
        
            elif(str(err)=="paymentModeMatchError"):

                return(
                    json.dumps(
                        {
                            "isValid":False,
                            "message":"Payment Mode not matching!",
                            "reward": None
                }))

            elif(str(err)=="orderPriceMatchError"):
                return(
                    json.dumps(
                        {
                            "isValid":False,
                            "message":"Total Order Price not matching!",
                            "reward": None
                }))

            elif(str(err)=="cartPriceMatchError"):
                return(
                    json.dumps(
                        {
                            "isValid":False,
                            "message":"Total Cart Price not matching!",
                            "reward": None
                }))

            elif(str(err)=="discountMatchError"):
                return(
                    json.dumps(
                        {
                            "isValid":False,
                            "message":"Total Discount not matching!",
                            "reward": None
                }))

            elif(str(err)=="fulfillmentMatchError"):

                return(
                    json.dumps(
                        {
                            "isValid":False,
                            "message":"Fulfillment not matching!",
                            "reward": None
                }))

            elif(str(err)=="productMatchError"):

                return(
                    json.dumps(
                        {
                            "isValid":False,
                            "message":"Cart Items not matching!",
                            "reward": None
                }))

            elif(str(err)=="rewardExpiredError"):

                return(
                    json.dumps(
                        {
                            "isValid":False,
                            "message":"Reward Expired!",
                            "reward": None
                }))

            else:

                return(
                    json.dumps(
                        {
                            "isValid":False,
                            "error":err,
                            "message":"Objects not matching/JWT Altered!",
                            "reward": None
                })
                   )



# coding: utf-8

"""
    marax-server-sdk

    Marax Server SDK to send transactional events from client server to marax server  # noqa: E501

    The version of the OpenAPI document: 0.3.0
    Contact: team@marax.ai
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from marax_server_sdk.configuration import Configuration


class RequestBodyProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'timestamp': 'datetime',
        'marax_id': 'str',
        'client_id': 'str',
        'reward': 'RequestBodyPropertiesReward',
        'payment_mode': 'str',
        'total_cart_price': 'RequestBodyPropertiesTotalCartPrice',
        'total_discount': 'RequestBodyPropertiesTotalDiscount',
        'total_order_price': 'RequestBodyPropertiesTotalOrderPrice',
        'products': 'list[RequestBodyPropertiesProducts]',
        'fulfillment': 'list[RequestBodyPropertiesFulfillment]'
    }

    attribute_map = {
        'timestamp': 'timestamp',
        'marax_id': 'maraxId',
        'client_id': 'clientId',
        'reward': 'reward',
        'payment_mode': 'paymentMode',
        'total_cart_price': 'totalCartPrice',
        'total_discount': 'totalDiscount',
        'total_order_price': 'totalOrderPrice',
        'products': 'products',
        'fulfillment': 'fulfillment'
    }

    def __init__(self, timestamp=None, marax_id=None, client_id=None, reward=None, payment_mode=None, total_cart_price=None, total_discount=None, total_order_price=None, products=None, fulfillment=None, local_vars_configuration=None):  # noqa: E501
        """RequestBodyProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._timestamp = None
        self._marax_id = None
        self._client_id = None
        self._reward = None
        self._payment_mode = None
        self._total_cart_price = None
        self._total_discount = None
        self._total_order_price = None
        self._products = None
        self._fulfillment = None
        self.discriminator = None

        if timestamp is not None:
            self.timestamp = timestamp
        if marax_id is not None:
            self.marax_id = marax_id
        if client_id is not None:
            self.client_id = client_id
        self.reward = reward
        if payment_mode is not None:
            self.payment_mode = payment_mode
        if total_cart_price is not None:
            self.total_cart_price = total_cart_price
        self.total_discount = total_discount
        self.total_order_price = total_order_price
        if products is not None:
            self.products = products
        if fulfillment is not None:
            self.fulfillment = fulfillment

    @property
    def timestamp(self):
        """Gets the timestamp of this RequestBodyProperties.  # noqa: E501


        :return: The timestamp of this RequestBodyProperties.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this RequestBodyProperties.


        :param timestamp: The timestamp of this RequestBodyProperties.  # noqa: E501
        :type: datetime
        """

        self._timestamp = timestamp

    @property
    def marax_id(self):
        """Gets the marax_id of this RequestBodyProperties.  # noqa: E501


        :return: The marax_id of this RequestBodyProperties.  # noqa: E501
        :rtype: str
        """
        return self._marax_id

    @marax_id.setter
    def marax_id(self, marax_id):
        """Sets the marax_id of this RequestBodyProperties.


        :param marax_id: The marax_id of this RequestBodyProperties.  # noqa: E501
        :type: str
        """

        self._marax_id = marax_id

    @property
    def client_id(self):
        """Gets the client_id of this RequestBodyProperties.  # noqa: E501


        :return: The client_id of this RequestBodyProperties.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this RequestBodyProperties.


        :param client_id: The client_id of this RequestBodyProperties.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def reward(self):
        """Gets the reward of this RequestBodyProperties.  # noqa: E501


        :return: The reward of this RequestBodyProperties.  # noqa: E501
        :rtype: RequestBodyPropertiesReward
        """
        return self._reward

    @reward.setter
    def reward(self, reward):
        """Sets the reward of this RequestBodyProperties.


        :param reward: The reward of this RequestBodyProperties.  # noqa: E501
        :type: RequestBodyPropertiesReward
        """

        self._reward = reward

    @property
    def payment_mode(self):
        """Gets the payment_mode of this RequestBodyProperties.  # noqa: E501


        :return: The payment_mode of this RequestBodyProperties.  # noqa: E501
        :rtype: str
        """
        return self._payment_mode

    @payment_mode.setter
    def payment_mode(self, payment_mode):
        """Sets the payment_mode of this RequestBodyProperties.


        :param payment_mode: The payment_mode of this RequestBodyProperties.  # noqa: E501
        :type: str
        """

        self._payment_mode = payment_mode

    @property
    def total_cart_price(self):
        """Gets the total_cart_price of this RequestBodyProperties.  # noqa: E501


        :return: The total_cart_price of this RequestBodyProperties.  # noqa: E501
        :rtype: RequestBodyPropertiesTotalCartPrice
        """
        return self._total_cart_price

    @total_cart_price.setter
    def total_cart_price(self, total_cart_price):
        """Sets the total_cart_price of this RequestBodyProperties.


        :param total_cart_price: The total_cart_price of this RequestBodyProperties.  # noqa: E501
        :type: RequestBodyPropertiesTotalCartPrice
        """

        self._total_cart_price = total_cart_price

    @property
    def total_discount(self):
        """Gets the total_discount of this RequestBodyProperties.  # noqa: E501


        :return: The total_discount of this RequestBodyProperties.  # noqa: E501
        :rtype: RequestBodyPropertiesTotalDiscount
        """
        return self._total_discount

    @total_discount.setter
    def total_discount(self, total_discount):
        """Sets the total_discount of this RequestBodyProperties.


        :param total_discount: The total_discount of this RequestBodyProperties.  # noqa: E501
        :type: RequestBodyPropertiesTotalDiscount
        """

        self._total_discount = total_discount

    @property
    def total_order_price(self):
        """Gets the total_order_price of this RequestBodyProperties.  # noqa: E501


        :return: The total_order_price of this RequestBodyProperties.  # noqa: E501
        :rtype: RequestBodyPropertiesTotalOrderPrice
        """
        return self._total_order_price

    @total_order_price.setter
    def total_order_price(self, total_order_price):
        """Sets the total_order_price of this RequestBodyProperties.


        :param total_order_price: The total_order_price of this RequestBodyProperties.  # noqa: E501
        :type: RequestBodyPropertiesTotalOrderPrice
        """

        self._total_order_price = total_order_price

    @property
    def products(self):
        """Gets the products of this RequestBodyProperties.  # noqa: E501


        :return: The products of this RequestBodyProperties.  # noqa: E501
        :rtype: list[RequestBodyPropertiesProducts]
        """
        return self._products

    @products.setter
    def products(self, products):
        """Sets the products of this RequestBodyProperties.


        :param products: The products of this RequestBodyProperties.  # noqa: E501
        :type: list[RequestBodyPropertiesProducts]
        """

        self._products = products

    @property
    def fulfillment(self):
        """Gets the fulfillment of this RequestBodyProperties.  # noqa: E501


        :return: The fulfillment of this RequestBodyProperties.  # noqa: E501
        :rtype: list[RequestBodyPropertiesFulfillment]
        """
        return self._fulfillment

    @fulfillment.setter
    def fulfillment(self, fulfillment):
        """Sets the fulfillment of this RequestBodyProperties.


        :param fulfillment: The fulfillment of this RequestBodyProperties.  # noqa: E501
        :type: list[RequestBodyPropertiesFulfillment]
        """

        self._fulfillment = fulfillment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RequestBodyProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RequestBodyProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    marax-server-sdk

    Marax Server SDK to send transactional events from client server to marax server  # noqa: E501

    The version of the OpenAPI document: 0.3.0
    Contact: team@marax.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import marax_server_sdk
from marax_server_sdk.models.response400 import Response400  # noqa: E501
from marax_server_sdk.rest import ApiException

class TestResponse400(unittest.TestCase):
    """Response400 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Response400
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = marax_server_sdk.models.response400.Response400()  # noqa: E501
        if include_optional :
            return Response400(
                status = 'error', 
                message = 'Invalid Body'
            )
        else :
            return Response400(
        )

    def testResponse400(self):
        """Test Response400"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    marax-server-sdk

    Marax Server SDK to send transactional events from client server to marax server  # noqa: E501

    The version of the OpenAPI document: 0.3.0
    Contact: team@marax.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from marax_server_sdk.api.reward_api import RewardApi

# import ApiClient
from marax_server_sdk.api_client import ApiClient
from marax_server_sdk.configuration import Configuration
from marax_server_sdk.exceptions import OpenApiException
from marax_server_sdk.exceptions import ApiTypeError
from marax_server_sdk.exceptions import ApiValueError
from marax_server_sdk.exceptions import ApiKeyError
from marax_server_sdk.exceptions import ApiException
# import models into sdk package
from marax_server_sdk.models.request_body import RequestBody
from marax_server_sdk.models.request_body_properties import RequestBodyProperties
from marax_server_sdk.models.request_body_properties_fulfillment import RequestBodyPropertiesFulfillment
from marax_server_sdk.models.request_body_properties_products import RequestBodyPropertiesProducts
from marax_server_sdk.models.request_body_properties_reward import RequestBodyPropertiesReward
from marax_server_sdk.models.request_body_properties_total_cart_price import RequestBodyPropertiesTotalCartPrice
from marax_server_sdk.models.request_body_properties_total_discount import RequestBodyPropertiesTotalDiscount
from marax_server_sdk.models.request_body_properties_total_order_price import RequestBodyPropertiesTotalOrderPrice
from marax_server_sdk.models.response200 import Response200
from marax_server_sdk.models.response400 import Response400
from marax_server_sdk.models.response500 import Response500




# coding: utf-8

"""
    marax-server-sdk

    Marax Server SDK to send transactional events from client server to marax server  # noqa: E501

    The version of the OpenAPI document: 0.3.0
    Contact: team@marax.ai
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from marax_server_sdk.configuration import Configuration


class RequestBodyPropertiesReward(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'expiry': 'datetime',
        'timezone': 'str',
        'promocode': 'str',
        'title': 'str',
        'body': 'str',
        'updated_at': 'datetime',
        'type': 'str',
        'ui': 'str',
        'handled_by': 'str'
    }

    attribute_map = {
        'id': 'id',
        'expiry': 'expiry',
        'timezone': 'timezone',
        'promocode': 'promocode',
        'title': 'title',
        'body': 'body',
        'updated_at': 'updatedAt',
        'type': 'type',
        'ui': 'ui',
        'handled_by': 'handledBy'
    }

    def __init__(self, id=None, expiry=None, timezone=None, promocode=None, title=None, body=None, updated_at=None, type=None, ui=None, handled_by=None, local_vars_configuration=None):  # noqa: E501
        """RequestBodyPropertiesReward - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._expiry = None
        self._timezone = None
        self._promocode = None
        self._title = None
        self._body = None
        self._updated_at = None
        self._type = None
        self._ui = None
        self._handled_by = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if expiry is not None:
            self.expiry = expiry
        if timezone is not None:
            self.timezone = timezone
        self.promocode = promocode
        self.title = title
        self.body = body
        if updated_at is not None:
            self.updated_at = updated_at
        if type is not None:
            self.type = type
        if ui is not None:
            self.ui = ui
        if handled_by is not None:
            self.handled_by = handled_by

    @property
    def id(self):
        """Gets the id of this RequestBodyPropertiesReward.  # noqa: E501


        :return: The id of this RequestBodyPropertiesReward.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RequestBodyPropertiesReward.


        :param id: The id of this RequestBodyPropertiesReward.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def expiry(self):
        """Gets the expiry of this RequestBodyPropertiesReward.  # noqa: E501


        :return: The expiry of this RequestBodyPropertiesReward.  # noqa: E501
        :rtype: datetime
        """
        return self._expiry

    @expiry.setter
    def expiry(self, expiry):
        """Sets the expiry of this RequestBodyPropertiesReward.


        :param expiry: The expiry of this RequestBodyPropertiesReward.  # noqa: E501
        :type: datetime
        """

        self._expiry = expiry

    @property
    def timezone(self):
        """Gets the timezone of this RequestBodyPropertiesReward.  # noqa: E501


        :return: The timezone of this RequestBodyPropertiesReward.  # noqa: E501
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """Sets the timezone of this RequestBodyPropertiesReward.


        :param timezone: The timezone of this RequestBodyPropertiesReward.  # noqa: E501
        :type: str
        """

        self._timezone = timezone

    @property
    def promocode(self):
        """Gets the promocode of this RequestBodyPropertiesReward.  # noqa: E501


        :return: The promocode of this RequestBodyPropertiesReward.  # noqa: E501
        :rtype: str
        """
        return self._promocode

    @promocode.setter
    def promocode(self, promocode):
        """Sets the promocode of this RequestBodyPropertiesReward.


        :param promocode: The promocode of this RequestBodyPropertiesReward.  # noqa: E501
        :type: str
        """

        self._promocode = promocode

    @property
    def title(self):
        """Gets the title of this RequestBodyPropertiesReward.  # noqa: E501


        :return: The title of this RequestBodyPropertiesReward.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this RequestBodyPropertiesReward.


        :param title: The title of this RequestBodyPropertiesReward.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def body(self):
        """Gets the body of this RequestBodyPropertiesReward.  # noqa: E501


        :return: The body of this RequestBodyPropertiesReward.  # noqa: E501
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this RequestBodyPropertiesReward.


        :param body: The body of this RequestBodyPropertiesReward.  # noqa: E501
        :type: str
        """

        self._body = body

    @property
    def updated_at(self):
        """Gets the updated_at of this RequestBodyPropertiesReward.  # noqa: E501


        :return: The updated_at of this RequestBodyPropertiesReward.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this RequestBodyPropertiesReward.


        :param updated_at: The updated_at of this RequestBodyPropertiesReward.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def type(self):
        """Gets the type of this RequestBodyPropertiesReward.  # noqa: E501


        :return: The type of this RequestBodyPropertiesReward.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RequestBodyPropertiesReward.


        :param type: The type of this RequestBodyPropertiesReward.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def ui(self):
        """Gets the ui of this RequestBodyPropertiesReward.  # noqa: E501


        :return: The ui of this RequestBodyPropertiesReward.  # noqa: E501
        :rtype: str
        """
        return self._ui

    @ui.setter
    def ui(self, ui):
        """Sets the ui of this RequestBodyPropertiesReward.


        :param ui: The ui of this RequestBodyPropertiesReward.  # noqa: E501
        :type: str
        """

        self._ui = ui

    @property
    def handled_by(self):
        """Gets the handled_by of this RequestBodyPropertiesReward.  # noqa: E501


        :return: The handled_by of this RequestBodyPropertiesReward.  # noqa: E501
        :rtype: str
        """
        return self._handled_by

    @handled_by.setter
    def handled_by(self, handled_by):
        """Sets the handled_by of this RequestBodyPropertiesReward.


        :param handled_by: The handled_by of this RequestBodyPropertiesReward.  # noqa: E501
        :type: str
        """
        allowed_values = ["marax", "client"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and handled_by not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `handled_by` ({0}), must be one of {1}"  # noqa: E501
                .format(handled_by, allowed_values)
            )

        self._handled_by = handled_by

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RequestBodyPropertiesReward):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RequestBodyPropertiesReward):
            return True

        return self.to_dict() != other.to_dict()
